/*
 * jGuild Project: jRPM
 * Released under the Apache License ( http://www.apache.org/LICENSE )
 */
package com.jguild.jrpm.io;

import java.io.DataInputStream;
import java.io.IOException;

import com.jguild.jrpm.io.constant.EnumIf;
import com.jguild.jrpm.io.constant.RPMHeaderTag;

/**
 * RPM Header.
 *
 * @version $Id: RPMHeader.java,v 1.7 2004/09/09 09:52:48 pnasrat Exp $
 */
public class RPMHeader extends Header {
    /**
     * Creates a new RPMHeader object out of an input stream.
     *
     * @param inputStream
     *           The input stream
     *
     * @throws IOException
     *            if an error occured during read of the rpm
     */
    public RPMHeader(DataInputStream inputStream) throws IOException {
        super(inputStream);
    }

    public RPMHeader(DataInputStream inputStream, boolean raw) throws IOException {
        super(inputStream, raw);
    }

    /**
     * @see com.jguild.jrpm.io.Header#getKnownTagNames()
     */
    public static String[] getKnownTagNames() {
        return RPMHeaderTag.getEnumNames();
    }

    /**
     * @see com.jguild.jrpm.io.Header#getTagIdForName(java.lang.String)
     */
    public long getTagIdForName(String tagname) {
        EnumIf e = RPMHeaderTag.getEnumByName(tagname);

        if (e == null) {
            throw new IllegalArgumentException("unknown tag with name <" + tagname + ">");
        }

        return e.getId();
    }

    /**
     * @see com.jguild.jrpm.io.Header#getTagNameForId(long)
     */
    public String getTagNameForId(long tagid) {
        EnumIf e = RPMHeaderTag.getEnumById(tagid);
        if (e == null) {
            throw new IllegalArgumentException("unknown tag with id <" + tagid + ">");
        }
        return e.getName();
    }

    /**
     * @see com.jguild.jrpm.io.Header#isValidTag(long)
     */
    public boolean isValidTag(long tagid) {
        return RPMHeaderTag.getEnumById(tagid) != null;
    }

    /**
     * @see com.jguild.jrpm.io.Header#isValidTag(java.lang.String)
     */
    public boolean isValidTag(String tagname) {
        return RPMHeaderTag.getEnumByName(tagname) != null;
    }
}
