/*
 * jGuild Project: jRPM Released under the Apache License (
 * http://www.apache.org/LICENSE )
 */
package com.jguild.jrpm.io.constant;


/**
 * Bit flags for dependency fields. (e.g. RPMHeaderTag.REQUIRE_FLAGS,
 * RPMHeaderTag.CONFLICT_FLAGS)
 *
 * @author kuss
 */
public class RPMSense implements FlagIf {
    public static final int _ANY = 0;
    public static final RPMSense ANY = new RPMSense(_ANY);

    /** @todo Legacy.  */
    public static final int _SERIAL = (1 << 0);
    public static final RPMSense SERIAL = new RPMSense(_SERIAL);
    public static final int _LESS = (1 << 1);
    public static final RPMSense LESS = new RPMSense(_LESS);
    public static final int _GREATER = (1 << 2);
    public static final RPMSense GREATER = new RPMSense(_GREATER);
    public static final int _EQUAL = (1 << 3);
    public static final RPMSense EQUAL = new RPMSense(_EQUAL);

    /** only used internally by builds */
    public static final int _PROVIDES = (1 << 4);
    public static final RPMSense PROVIDES = new RPMSense(_PROVIDES);

    /** only used internally by builds */
    public static final int _CONFLICTS = (1 << 5);
    public static final RPMSense CONFLICTS = new RPMSense(_CONFLICTS);

    /** @todo Legacy.  */
    public static final int _PREREQ = (1 << 6);
    public static final RPMSense PREREQ = new RPMSense(_PREREQ);

    /** only used internally by builds */
    public static final int _OBSOLETES = (1 << 7);
    public static final RPMSense OBSOLETES = new RPMSense(_OBSOLETES);

    /** Interpreter used by scriptlet.  */
    public static final int _INTERP = (1 << 8);
    public static final RPMSense INTERP = new RPMSense(_INTERP);

    /** %pre dependency.  */
    public static final int _SCRIPT_PRE = ((1 << 9) | _PREREQ);
    public static final RPMSense SCRIPT_PRE = new RPMSense(_SCRIPT_PRE);

    /** %post dependency.  */
    public static final int _SCRIPT_POST = ((1 << 10) | _PREREQ);
    public static final RPMSense SCRIPT_POST = new RPMSense(_SCRIPT_POST);

    /** %preun dependency.  */
    public static final int _SCRIPT_PREUN = ((1 << 11) | _PREREQ);
    public static final RPMSense SCRIPT_PREUN = new RPMSense(_SCRIPT_PREUN);

    /** %postun dependency.  */
    public static final int _SCRIPT_POSTUN = ((1 << 12) | _PREREQ);
    public static final RPMSense SCRIPT_POSTUN = new RPMSense(_SCRIPT_POSTUN);

    /** %verify dependency.  */
    public static final int _SCRIPT_VERIFY = (1 << 13);
    public static final RPMSense SCRIPT_VERIFY = new RPMSense(_SCRIPT_VERIFY);

    /** find-requires generated dependency.  */
    public static final int _FIND_REQUIRES = (1 << 14);
    public static final RPMSense FIND_REQUIRES = new RPMSense(_FIND_REQUIRES);

    /** find-provides generated dependency.  */
    public static final int _FIND_PROVIDES = (1 << 15);
    public static final RPMSense FIND_PROVIDES = new RPMSense(_FIND_PROVIDES);

    /** %triggerin dependency.  */
    public static final int _TRIGGERIN = (1 << 16);
    public static final RPMSense TRIGGERIN = new RPMSense(_TRIGGERIN);

    /** %triggerun dependency.  */
    public static final int _TRIGGERUN = (1 << 17);
    public static final RPMSense TRIGGERUN = new RPMSense(_TRIGGERUN);

    /** %triggerpostun dependency.  */
    public static final int _TRIGGERPOSTUN = (1 << 18);
    public static final RPMSense TRIGGERPOSTUN = new RPMSense(_TRIGGERPOSTUN);

    // (1 << 19) unused.

    /** %prep build dependency.  */
    public static final int _SCRIPT_PREP = (1 << 20);
    public static final RPMSense SCRIPT_PREP = new RPMSense(_SCRIPT_PREP);

    /** %build build dependency.  */
    public static final int _SCRIPT_BUILD = (1 << 21);
    public static final RPMSense SCRIPT_BUILD = new RPMSense(_SCRIPT_BUILD);

    /** %install build dependency.  */
    public static final int _SCRIPT_INSTALL = (1 << 22);
    public static final RPMSense SCRIPT_INSTALL = new RPMSense(_SCRIPT_INSTALL);

    /** %clean build dependency.  */
    public static final int _SCRIPT_CLEAN = (1 << 23);
    public static final RPMSense SCRIPT_CLEAN = new RPMSense(_SCRIPT_CLEAN);

    /** rpmlib(feature) dependency.  */
    public static final int _RPMLIB = ((1 << 24) | _PREREQ);
    public static final RPMSense RPMLIB = new RPMSense(_RPMLIB);

    /** @todo Implement %triggerprein.  */
    public static final int _TRIGGERPREIN = (1 << 25);
    public static final RPMSense TRIGGERPREIN = new RPMSense(_TRIGGERPREIN);
    public static final int _KEYRING = (1 << 26);
    public static final RPMSense KEYRING = new RPMSense(_KEYRING);
    public static final int _PATCHES = (1 << 27);
    public static final RPMSense PATCHES = new RPMSense(_PATCHES);
    public static final int _CONFIG = (1 << 28);
    public static final RPMSense CONFIG = new RPMSense(_CONFIG);

    // Some masks

    /**
     * Mask to get senses, ie serial,
     * less, greater, equal.
     */
    public static final int _SENSEMASK = 15;
    public static final RPMSense SENSEMASK = new RPMSense(_SENSEMASK);
    public static final int _TRIGGER = _TRIGGERIN | _TRIGGERUN | _TRIGGERPOSTUN;
    public static final RPMSense TRIGGER = new RPMSense(_TRIGGER);
    public static final int _ALL_REQUIRES_MASK = _INTERP | _SCRIPT_PRE | _SCRIPT_POST | _SCRIPT_PREUN | _SCRIPT_POSTUN | _SCRIPT_VERIFY | _FIND_REQUIRES |
        _SCRIPT_PREP | _SCRIPT_BUILD | _SCRIPT_INSTALL | _SCRIPT_CLEAN | _RPMLIB | _KEYRING;
    public static final RPMSense ALL_REQUIRES_MASK = new RPMSense(_ALL_REQUIRES_MASK);
    private final int flag;

    private RPMSense(int flag) {
        this.flag = flag;
    }

    /*
     * @see com.jguild.jrpm.io.constant.FlagIf#value()
     */
    public int value() {
        return flag;
    }
}
