/*
 * jGuild Project: jRPM
 * Released under the Apache License ( http://www.apache.org/LICENSE )
 */
package com.jguild.jrpm.io.constant;


/**
 * Constants for signature tags.
 *
 * @version $Id: RPMSignatureTag.java,v 1.4 2004/05/06 20:59:24 mkuss Exp $
 */
public final class RPMSignatureTag implements EnumIf {
    public static final RPMSignatureTag UNKNOWN = new RPMSignatureTag(_UNKNOWN, "UNKNOWN");
    public static final int _HEADERSIGNATURES = 62;
    public static final RPMSignatureTag HEADERSIGNATURES = new RPMSignatureTag(_HEADERSIGNATURES, "HEADERSIGNATURES");
    public static final int _BADSHA1_1 = 264;
    public static final RPMSignatureTag BADSHA1_1 = new RPMSignatureTag(_BADSHA1_1, "BADSHA1_1");
    public static final int _BADSHA1_2 = 265;
    public static final RPMSignatureTag BADSHA1_2 = new RPMSignatureTag(_BADSHA1_2, "BADSHA1_2");
    public static final int _DSA = 267;
    public static final RPMSignatureTag DSA = new RPMSignatureTag(_DSA, "DSA");
    public static final int _RSA = 268;
    public static final RPMSignatureTag RSA = new RPMSignatureTag(_RSA, "RSA");
    public static final int _SHA1 = 269;
    public static final RPMSignatureTag SHA1 = new RPMSignatureTag(_SHA1, "SHA1");
    public static final int _SIZE = 1000;
    public static final RPMSignatureTag SIZE = new RPMSignatureTag(_SIZE, "SIZE");
    public static final int _LEMD5_1 = 1001;
    public static final RPMSignatureTag LEMD5_1 = new RPMSignatureTag(_LEMD5_1, "LEMD5_1");
    public static final int _PGP = 1002;
    public static final RPMSignatureTag PGP = new RPMSignatureTag(_PGP, "PGP");
    public static final int _LEMD5_2 = 1003;
    public static final RPMSignatureTag LEMD5_2 = new RPMSignatureTag(_LEMD5_2, "LEMD5_2");
    public static final int _MD5 = 1004;
    public static final RPMSignatureTag MD5 = new RPMSignatureTag(_MD5, "MD5");
    public static final int _GPG = 1005;
    public static final RPMSignatureTag GPG = new RPMSignatureTag(_GPG, "GPG");
    public static final int _PGP5 = 1006;
    public static final RPMSignatureTag PGP5 = new RPMSignatureTag(_PGP5, "PGP5");
    public static final int _PAYLOADSIZE = 1007;
    public static final RPMSignatureTag PAYLOADSIZE = new RPMSignatureTag(_PAYLOADSIZE, "PAYLOADSIZE");
    private EnumIf delegate;

    private RPMSignatureTag(int signature, String name) {
        delegate = new EnumDelegate(RPMSignatureTag.class, signature, name, this);
    }

    /**
     * Get a enum by id
     *
     * @param id The id of the enum
     * @return The enum object
     */
    public static EnumIf getEnumById(long id) {
        return EnumDelegate.getEnumById(RPMSignatureTag.class, id);
    }

    /**
     * Get a enum by name
     *
     * @param name The name of the enum
     * @return The enum object
     */
    public static EnumIf getEnumByName(String name) {
        return EnumDelegate.getEnumByName(RPMSignatureTag.class, name);
    }

    /**
     * Get all defined enums of this class
     *
     * @return An array of all defined enum objects
     */
    public static String[] getEnumNames() {
        return EnumDelegate.getEnumNames(RPMSignatureTag.class);
    }

    /**
     * Get a enum of this class by id
     *
     * @param signature The id
     * @return The enum object
     */
    public static RPMSignatureTag getRPMSignatureTag(int signature) {
        return (RPMSignatureTag) getEnumById(signature);
    }

    /**
     * Check if this enum class contains a enum of a specified id
     *
     * @param id The id of the enum
     * @return TRUE if the enum is defined in this class
     */
    public static boolean containsEnumId(Long id) {
        return EnumDelegate.containsEnumId(RPMSignatureTag.class, id);
    }

    /*
     * @see com.jguild.jrpm.io.constant.EnumIf#getId()
     */
    public long getId() {
        return delegate.getId();
    }

    /*
     * @see com.jguild.jrpm.io.constant.EnumIf#getName()
     */
    public String getName() {
        return delegate.getName();
    }

    /*
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return delegate.toString();
    }
}
