/*
 * jGuild Project: jRPM
 * Released under the Apache License ( http://www.apache.org/LICENSE )
 */
package com.jguild.jrpm.io.cpio;

/**
 * All constants needed by CPIO.
 * 
 * @author Michael Kuss
 */
public interface CPIOConstants {
    /** magic number of a cpio entry in the new format */
    static final String MAGIC_NEW = "070701";

    /** magic number of a cpio entry in the new format with crc */
    static final String MAGIC_NEW_CRC = "070702";

    /** magic number of a cpio entry in the old ascii format */
    static final String MAGIC_OLD_ASCII = "070707";

    /** magic number of a cpio entry in the old binary format */
    static final int MAGIC_OLD_BINARY = 070707;

    /** write/read a CPIOEntry in the new format */
    static final short FORMAT_NEW = 1;

    /** write/read a CPIOEntry in the new format with crc */
    static final short FORMAT_NEW_CRC = 2;

    /** write/read a CPIOEntry in the old ascii format */
    static final short FORMAT_OLD_ASCII = 4;

    /** write/read a CPIOEntry in the old binary format */
    static final short FORMAT_OLD_BINARY = 8;

    /** Mask for both new formats */
    static final short FORMAT_NEW_MASK = 3;

    /** Mask for both old formats */
    static final short FORMAT_OLD_MASK = 12;

    /** Mask for all file type bits. */
    static final int S_IFMT = 0170000;

    /** Defines a directory */
    static final int C_ISDIR = 0040000;

    /** Defines a symbolic link */
    static final int C_ISLNK = 0120000;

    /** Defines a regular file */
    static final int C_ISREG = 0100000;

    /** Defines a pipe */
    static final int C_ISFIFO = 0010000;

    /** Defines a character device */
    static final int C_ISCHR = 0020000;

    /** Defines a block device */
    static final int C_ISBLK = 0060000;

    /** Defines a socket */
    static final int C_ISSOCK = 0140000;

    /** HP/UX network special (C_ISCTG) */
    static final int C_ISNWK = 0110000;

    /** Permits the owner of a file to read the file */
    static final int C_IRUSR = 000400;

    /** Permits the owner of a file to write to the file */
    static final int C_IWUSR = 000200;

    /**
     * Permits the owner of a file to execute the file or to search the file's
     * directory
     */
    static final int C_IXUSR = 000100;

    /** Permits a file's group to read the file */
    static final int C_IRGRP = 000040;

    /** Permits a file's group to write to the file */
    static final int C_IWGRP = 000020;

    /**
     * Permits a file's group to execute the file or to search the file's
     * directory
     */
    static final int C_IXGRP = 000010;

    /** Permits others to read the file */
    static final int C_IROTH = 000004;

    /** Permits others to write to the file */
    static final int C_IWOTH = 000002;

    /** Permits others to execute the file or to search the file's directory */
    static final int C_IXOTH = 000001;

    /** TODO document */
    static final int C_ISUID = 004000;

    /** TODO document */
    static final int C_ISGID = 002000;

    /** TODO document */
    static final int C_ISVTX = 001000;
}
